@@ -67,8 +67,10 @@ static gboolean         alsa_device_check_io            (BsePcmHandle
 static guint            alsa_device_latency             (BsePcmHandle           *handle);
 
 /* --- define object type and export to BSE --- */
-BSE_REGISTER_OBJECT (BsePcmDeviceALSA, BsePcmDevice, NULL, NULL, NULL, bse_pcm_device_alsa_class_init, NULL, bse_pcm_device_alsa_init);
-BSE_DEFINE_EXPORTS (__FILE__);
+static const char type_blurb[] = ("PCM driver implementation for the Advanced Linux Sound Architecture "
+                                  "(http://alsa-project.org/alsa-doc/alsa-lib/pcm.html)");
+BSE_REGISTER_OBJECT (BsePcmDeviceALSA, BsePcmDevice, NULL, "", type_blurb, NULL, bse_pcm_device_alsa_class_init, NULL, bse_pcm_device_alsa_init);
+BSE_DEFINE_EXPORTS ();
 
 /* --- variables --- */
 static gpointer parent_class = NULL;
